==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1ClusterPipelineTemplateFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import io.kubernetes.client.models.V1ObjectMeta;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1ClusterPipelineTemplateFluent<A extends V1alpha1ClusterPipelineTemplateFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public V1ObjectMeta getMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTemplateSpec getSpec();
    public V1alpha1PipelineTemplateSpec buildSpec();
    public A withSpec(V1alpha1PipelineTemplateSpec spec);
    public Boolean hasSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> withNewSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> withNewSpecLike(V1alpha1PipelineTemplateSpec item);
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editOrNewSpecLike(V1alpha1PipelineTemplateSpec item);

    public interface SpecNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTemplateSpecFluent<V1alpha1ClusterPipelineTemplateFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ClusterPipelineTemplateFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import io.kubernetes.client.models.V1ObjectMeta;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1ClusterPipelineTemplateFluent<A extends V1alpha1ClusterPipelineTemplateFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public V1ObjectMeta getMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTemplateSpec getSpec();
    public V1alpha1PipelineTemplateSpec buildSpec();
    public A withSpec(V1alpha1PipelineTemplateSpec spec);
    public Boolean hasSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> withNewSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> withNewSpecLike(V1alpha1PipelineTemplateSpec item);
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1ClusterPipelineTemplateFluent.SpecNested<A> editOrNewSpecLike(V1alpha1PipelineTemplateSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1TemplateStatus getStatus();
    public V1alpha1TemplateStatus buildStatus();
    public A withStatus(V1alpha1TemplateStatus status);
    public Boolean hasStatus();
    public V1alpha1ClusterPipelineTemplateFluent.StatusNested<A> withNewStatus();
    public V1alpha1ClusterPipelineTemplateFluent.StatusNested<A> withNewStatusLike(V1alpha1TemplateStatus item);
    public V1alpha1ClusterPipelineTemplateFluent.StatusNested<A> editStatus();
    public V1alpha1ClusterPipelineTemplateFluent.StatusNested<A> editOrNewStatus();
    public V1alpha1ClusterPipelineTemplateFluent.StatusNested<A> editOrNewStatusLike(V1alpha1TemplateStatus item);

    public interface SpecNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTemplateSpecFluent<V1alpha1ClusterPipelineTemplateFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1TemplateStatusFluent<V1alpha1ClusterPipelineTemplateFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
